@@ -73,6 +73,7 @@ namespace Lum {
       bool                    enabled;
 
     private:
+      void PrependObject(MsgObject* object);
       void AddObject(MsgObject* object);
       void RemoveObject(MsgObject* object);
 
@@ -133,6 +134,7 @@ namespace Lum {
       std::wstring GetName() const;
 
       void Observe(Model* model);
+      void ObservePrior(Model* model);
       void Forget(Model* model);
       virtual void Resync(Model* model, const ResyncMsg& msg);
     };
