@@ -185,9 +185,10 @@ namespace Lum {
     standard font is completly visible. A non-standard height might be
     necessary if you choose a non-standard font are graphical elements.
   */
-  void TableView::SetRowHeight(int height)
+  void TableView::SetRowHeight(size_t height)
   {
-    rowHeight=height;
+    rowHeight=std::max(OS::display->GetTheme()->GetMinimalTableRowHeight(),
+                       height);
   }
 
   void TableView::RecalcTableWidth()
@@ -332,6 +333,8 @@ namespace Lum {
       return;
     }
 
+    size_t rh=0;
+
     for (size_t x=1; x<=this->header->GetColumns(); x++) {
       Object *object=this->model->GetObject(x,1);
 
@@ -342,13 +345,15 @@ namespace Lum {
           object->CalcSize();
         }
 
-        rowHeight=std::max(rowHeight,object->GetOHeight());
+        rh=std::max(rh,object->GetOHeight());
 
       }
       else {
-        rowHeight=std::max(rowHeight,font->height);
+        rh=std::max(rh,font->height);
       }
     }
+
+    SetRowHeight(rh);
   }
 
   void TableView::FitColumns()
@@ -442,16 +447,22 @@ namespace Lum {
 
   void TableView::UpdateDimensions()
   {
-    if (model.Valid() && !model->IsNull()) {
+    if (model.Valid() && !model->IsNull() &&
+        (model->GetRows()>0 || (header.Valid() && header->GetColumns()>1))) {
       hAdjustment->SetStepSize(font->StringWidth(L"m"));
       hAdjustment->SetDimension(width,tableWidth);
+    }
+    else {
+      hAdjustment->SetInvalid();
+    }
+
+    if (model.Valid() && !model->IsNull() && model->GetRows()>0) {
       if (rowHeight!=0) {
         vAdjustment->SetStepSize(rowHeight);
         vAdjustment->SetDimension(height,model->GetRows()*rowHeight);
       }
     }
     else {
-      hAdjustment->SetInvalid();
       vAdjustment->SetInvalid();
     }
   }
@@ -652,7 +663,6 @@ namespace Lum {
       back->Draw(draw,
                  x,y,this->x+width-x+1,rowHeight,
                  x,y,this->x+width-x+1,rowHeight);
-
     }
 
     if (selection.Valid() &&
@@ -718,13 +728,13 @@ namespace Lum {
 
   void TableView::CalcSize()
   {
-    minWidth=10;
-    minHeight=3*font->height;
+    minWidth=10; //TODO Make this font relative
+    minHeight=std::max(font->height,OS::display->GetTheme()->GetMinimalTableRowHeight());
 
     width=minWidth;
 
     if (autoVSize && model.Valid()) {
-      height=model->GetRows()*font->height;
+      height=model->GetRows()*std::max(font->height,OS::display->GetTheme()->GetMinimalTableRowHeight());
       if (header->GetColumns()==1 && !autoHSize) {
         // This is a hack!
         // TableView does know, that GetParent()->GetParent() is normally of type
@@ -1197,7 +1207,11 @@ namespace Lum {
         }
 
         fullRefresh=true;
-        vAdjustment->SetTop(1);
+        UpdateDimensions();
+
+        if (this->model->GetRows()>0) {
+          vAdjustment->SetTop(1);
+        }
         Redraw();
       }
       else if (model==vAdjustment->GetTopModel()) {
